Rename freq_scale to a less generic name, as it will get exported soon
for modules. Since x86 already names its own implementation of this as
arch_freq_scale, lets stick to that.

Suggested-by: Will Deacon <w...@kernel.org>
Signed-off-by: Viresh Kumar <viresh.ku...@linaro.org>
---
 arch/arm64/kernel/topology.c  | 6 +++---
 drivers/base/arch_topology.c  | 4 ++--
 include/linux/arch_topology.h | 4 ++--
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/drivers/base/arch_topology.c b/drivers/base/arch_topology.c
index de8587cc119e..2a1cecbde0a4 100644
--- a/drivers/base/arch_topology.c
+++ b/drivers/base/arch_topology.c
@@ -31,7 +31,7 @@ __weak bool arch_freq_counters_available(const struct cpumask 
*cpus)
 {
        return false;
 }
-DEFINE_PER_CPU(unsigned long, freq_scale) = SCHED_CAPACITY_SCALE;
+DEFINE_PER_CPU(unsigned long, arch_freq_scale) = SCHED_CAPACITY_SCALE;
 
 void topology_set_freq_scale(const struct cpumask *cpus, unsigned long 
cur_freq,
                             unsigned long max_freq)
@@ -53,7 +53,7 @@ void topology_set_freq_scale(const struct cpumask *cpus, 
unsigned long cur_freq,
        scale = (cur_freq << SCHED_CAPACITY_SHIFT) / max_freq;
 
        for_each_cpu(i, cpus)
-               per_cpu(freq_scale, i) = scale;
+               per_cpu(arch_freq_scale, i) = scale;
 }
 
 DEFINE_PER_CPU(unsigned long, cpu_scale) = SCHED_CAPACITY_SCALE;
diff --git a/include/linux/arch_topology.h b/include/linux/arch_topology.h
index 0f6cd6b73a61..583af517f123 100644
--- a/include/linux/arch_topology.h
+++ b/include/linux/arch_topology.h
@@ -23,11 +23,11 @@ static inline unsigned long topology_get_cpu_scale(int cpu)
 
 void topology_set_cpu_scale(unsigned int cpu, unsigned long capacity);
 
-DECLARE_PER_CPU(unsigned long, freq_scale);
+DECLARE_PER_CPU(unsigned long, arch_freq_scale);
 
 static inline unsigned long topology_get_freq_scale(int cpu)
 {
-       return per_cpu(freq_scale, cpu);
+       return per_cpu(arch_freq_scale, cpu);
 }
 
 void topology_set_freq_scale(const struct cpumask *cpus, unsigned long 
cur_freq,
diff --git a/arch/arm64/kernel/topology.c b/arch/arm64/kernel/topology.c
index e08a4126453a..aa8d893619ed 100644
--- a/arch/arm64/kernel/topology.c
+++ b/arch/arm64/kernel/topology.c
@@ -256,8 +256,8 @@ static int init_amu_fie_callback(struct notifier_block *nb, 
unsigned long val,
         * initialized AMU support and enabled invariance. The AMU counters will
         * keep on working just fine in the absence of the cpufreq driver, and
         * for the CPUs for which there are no counters available, the last set
         * value of freq_scale will remain valid as that is the frequency those
         * CPUs are running at.
         */
 
        return 0;
@@ -327,7 +327,7 @@ void topology_scale_freq_tick(void)
                          const_cnt - prev_const_cnt);
 
        scale = min_t(unsigned long, scale, SCHED_CAPACITY_SCALE);
-       this_cpu_write(freq_scale, (unsigned long)scale);
+       this_cpu_write(arch_freq_scale, (unsigned long)scale);
 }
 
 #ifdef CONFIG_ACPI_CPPC_LIB
@@ -256,8 +256,8 @@ static int init_amu_fie_callback(struct notifier_block *nb, 
         * keep on working just fine in the absence of the cpufreq driver, and
         * for the CPUs for which there are no counters available, the last set
-        * value of freq_scale will remain valid as that is the frequency those
-        * CPUs are running at.
+        * value of arch_freq_scale will remain valid as that is the frequency
+        * those CPUs are running at.
         */
 
-- 
2.25.0.rc1.19.g042ed3e048af

Reply via email to